bayespy.inference.vmp.nodes.bernoulli.BernoulliMoments.compute_fixed_moments
============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.bernoulli

.. automethod:: BernoulliMoments.compute_fixed_moments